@@ -3,4 +3,4 @@
 """
 
 from .authcookie import AuthenticatedCookieMiddleware
-from .redirect_root import redirect_root, graphql_info
\ No newline at end of file
+from .redirect_root import redirect_root
