@@ -3,5 +3,5 @@
 """
 
 from .mongo import Mongo
-from .querying import manager
+from .admin import manager
 from .sql import SQL
